"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.formatSQLForDebugging = formatSQLForDebugging;

var _debug = require("debug");

var _debug2 = _interopRequireDefault(_debug);

var _chalk = require("chalk");

var _chalk2 = _interopRequireDefault(_chalk);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function formatSQLForDebugging(sql) {
  let colourIndex = 0;
  let allowedColours = [_chalk2.default.red, _chalk2.default.green, _chalk2.default.yellow, _chalk2.default.blue, _chalk2.default.magenta, _chalk2.default.cyan, _chalk2.default.white, _chalk2.default.black];
  function nextColor() {
    colourIndex = (colourIndex + 1) % allowedColours.length;
    return allowedColours[colourIndex];
  }
  const colours = {};

  /* Yep - that's `colour` from English and `ize` from American */
  function colourize(str) {
    if (!colours[str]) {
      colours[str] = nextColor();
    }
    return colours[str].bold.call(null, str);
  }

  let indentLevel = 0;
  function handleIndent(all, rawMatch) {
    const match = rawMatch.replace(/ $/, "");
    if (match === "(") {
      indentLevel++;
      return match + "\n" + "  ".repeat(indentLevel);
    } else if (match === ")") {
      indentLevel--;
      return "\n" + "  ".repeat(indentLevel) + match;
    } else if (match === "),") {
      indentLevel--;
      return "\n" + "  ".repeat(indentLevel) + match + "\n" + "  ".repeat(indentLevel);
    } else if (match === ",") {
      return match + "\n" + "  ".repeat(indentLevel);
    } else {
      return "\n" + "  ".repeat(indentLevel) + match.replace(/^\s+/, "");
    }
  }
  const tidySql = sql.replace(/\s+/g, " ").replace(/\s+(?=$|\n|\))/g, "").replace(/(\n|^|\()\s+/g, "$1").replace(/(\(|\)|\), ?|, ?| (select|insert|update|delete|from|where|and|or|order|limit)(?= ))/g, handleIndent).replace(/\(\s*([A-Za-z0-9_."' =]{1,50})\s*\)/g, "($1)").replace(/\(\s*(\([A-Za-z0-9_."' =]{1,50}\))\s*\)/g, "($1)").replace(/\n\s*and \(TRUE\)/g, _chalk2.default.gray(" and (TRUE)"));
  const colouredSql = tidySql.replace(/__local_[0-9]+__/g, colourize);
  return colouredSql;
}

const rawDebugSql = (0, _debug2.default)("graphile-build-pg:sql");

function debugSql(sql) {
  if (!rawDebugSql.enabled) {
    return;
  }
  rawDebugSql("%s", "\n" + formatSQLForDebugging(sql));
}
Object.assign(debugSql, rawDebugSql);

exports.default = debugSql;
//# sourceMappingURL=debugSql.js.map